%define pypi_name pymongo

Name:           python-%{pypi_name}
Version:        4.6.3
Release:        %mkrel 2
Summary:        Python driver for MongoDB
Group:          Development/Python
# All code is ASL 2.0 except bson/time64*.{c,h} which is MIT
License:        ASL 2.0 and MIT
URL:            https://pypi.org/project/pymongo/
Source0:        %{pypi_source}
BuildRequires:  python3-devel
BuildRequires:  python3dist(sphinx)

%description
The Python driver for MongoDB.

%package -n     python3-%{pypi_name}
Summary:        Python3 driver for MongoDB
Requires:       python3-bson >= %{version}-%{release}
Obsoletes:      python-pymongo-doc < 4.6.1

%description -n python3-%{pypi_name}
The Python 3 driver for MongoDB.

%package -n     python3-gridfs
Summary:        Python 3 GridFS driver for MongoDB
Requires:       python3-%{pypi_name} >= %{version}-%{release}
Provides:       python%{python3_pkgversion}dist(gridfs) = %{version}
Provides:       python%{python3_version}dist(gridfs) = %{version}
%{?python_provide:%python_provide python3-gridfs}

%description -n python3-gridfs
GridFS is a storage specification for large objects in MongoDB.

%package -n     python3-bson
Summary:        Python 3 bson library
Provides:	python%{python3_pkgversion}dist(bson) = %{version}
Provides:       python%{python3_version}dist(bson) = %{version}
%{?python_provide:%python_provide python3-bson}

%description -n python3-bson
BSON is a binary-encoded serialization of JSON-like documents. BSON is designed
to be lightweight, traversable, and efficient. BSON, like JSON, supports the
embedding of objects and arrays within other objects and arrays.

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

# Generating documention
PYTHONPATH=$PWD/build/lib.%{python3_platform}-cpython-%{python3_version_nodots} \
  sphinx-build -M html doc doc/html

# Clean leftovers
rm -rf doc/html/html/.{buildinfo,doctrees}

%install
%pyproject_install

%files -n python3-%{pypi_name}
%doc README.rst doc/html/html
%license LICENSE
%{python3_sitearch}/%{pypi_name}/
%{python3_sitearch}/%{pypi_name}-%{version}.dist-info/

%files -n python3-gridfs
%doc README.rst
%license LICENSE
%{python3_sitearch}/gridfs/

%files -n python3-bson
%doc README.rst
%license LICENSE
%{python3_sitearch}/bson/


%changelog
* Sat Mar 01 2025 wally <wally> 4.6.3-2.mga10
+ Revision: 2155632
- rebuild for python3.13

* Sat May 18 2024 daviddavid <daviddavid> 4.6.3-1.mga10
+ Revision: 2064715
- new version: 4.6.3, fixes CVE-2024-21506 (mga#33202)

* Wed Feb 21 2024 wally <wally> 4.6.1-2.mga10
+ Revision: 2042832
- add manual pydist provides to bson and gridfs

* Wed Feb 21 2024 wally <wally> 4.6.1-1.mga10
+ Revision: 2042831
- new version 4.6.1
- drop separate doc pkg

* Tue Jan 23 2024 daviddavid <daviddavid> 4.3.3-3.mga10
+ Revision: 2033662
- switch to pyproject

* Tue Jan 23 2024 daviddavid <daviddavid> 4.3.3-2.mga10
+ Revision: 2033657
- rebuild for py3.12
- fix python3 sub-pkg summary

* Wed Jan 25 2023 guillomovitch <guillomovitch> 4.3.3-1.mga9
+ Revision: 1936054
- new version 4.3.3

* Fri Mar 18 2022 umeabot <umeabot> 4.0.1-2.mga9
+ Revision: 1799121
- Mageia 9 Mass Rebuild

* Tue Feb 15 2022 mrambo3501 <mrambo3501> 4.0.1-1.mga9
+ Revision: 1775546
- version 4.0.1
- rebuild for python-3.10

* Sat Mar 20 2021 guillomovitch <guillomovitch> 3.11.3-1.mga9
+ Revision: 1706026
- new version 3.11.3

* Wed Feb 19 2020 umeabot <umeabot> 3.10.1-2.mga8
+ Revision: 1544316
- Mageia 8 Mass Rebuild

* Sat Jan 25 2020 guillomovitch <guillomovitch> 3.10.1-1.mga8
+ Revision: 1482835
- new version 3.10.1

* Fri Oct 11 2019 tv <tv> 3.8.0-3.mga8
+ Revision: 1451522
- rebuild for python-3.8
- drop python2 subpkg

* Sat Aug 24 2019 wally <wally> 3.8.0-2.mga8
+ Revision: 1431797
- update doc build

* Mon Jul 01 2019 guillomovitch <guillomovitch> 3.8.0-1.mga8
+ Revision: 1417244
- drop failing tests
- new version 3.8.0

* Mon Jan 07 2019 shlomif <shlomif> 3.7.2-1.mga7
+ Revision: 1351501
- Rebuild for python3 3.7

* Sun Sep 23 2018 umeabot <umeabot> 3.7.1-2.mga7
+ Revision: 1300572
- Mageia 7 Mass Rebuild

* Mon Jul 30 2018 daviddavid <daviddavid> 3.7.1-1.mga7
+ Revision: 1245928
- new version: 3.7.1
- remove merged upstream patch

* Fri Mar 09 2018 daviddavid <daviddavid> 3.6.1-1.mga7
+ Revision: 1207551
- new version: 3.6.1
- add upstream patch to fix Sphinx 1.7 support

* Thu Feb 22 2018 daviddavid <daviddavid> 3.6.0-2.mga7
+ Revision: 1204235
- fix requires

* Tue Feb 20 2018 daviddavid <daviddavid> 3.6.0-1.mga7
+ Revision: 1203595
- new version: 3.6.0
- rename all python-xxxx subpakages to python2-xxxx
- restore python-pymongo from mga5 branch (mga#22633)

* Wed Oct 15 2014 umeabot <umeabot> 2.5.2-9.mga5
+ Revision: 747613
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 2.5.2-8.mga5
+ Revision: 729470
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 2.5.2-7.mga5
+ Revision: 688264
- Mageia 5 Mass Rebuild

* Sat May 31 2014 pterjan <pterjan> 2.5.2-6.mga5
+ Revision: 628953
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 2.5.2-5.mga4
+ Revision: 544103
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 2.5.2-4.mga4
+ Revision: 499243
- Rebuild to add different pythonegg provides for python 2 and 3

* Wed Sep 04 2013 fwang <fwang> 2.5.2-3.mga4
+ Revision: 475007
- obsolete old package

* Tue Sep 03 2013 guillomovitch <guillomovitch> 2.5.2-2.mga4
+ Revision: 474861
- add python3 version

* Wed Jun 19 2013 guillomovitch <guillomovitch> 2.5.2-1.mga4
+ Revision: 445111
- new version

* Tue Apr 16 2013 guillomovitch <guillomovitch> 2.5-1.mga3
+ Revision: 410229
- imported package python-pymongo

